summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorRobert Moore <Robert.Moore@intel.com>2014-01-28 08:23:36 -0800
committerRobert Moore <Robert.Moore@intel.com>2014-01-28 08:23:36 -0800
commit053b198353718688bef0bec7f0d65493ab505bc9 (patch)
tree8bb35a572423f07452530273335e33bb22976d1c
parent1861f7ba951af6ca0277b9fa9a8eb1616a1ea36d (diff)
Add additional named objects for the auto-serialize method scan.
This change adds some additional opcodes that are detected and will cause a method to be auto-serialized. These opcodes are the various CreateXField and the FieldUnit opcodes. Lv Zheng.
-rw-r--r--source/components/dispatcher/dsmethod.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/source/components/dispatcher/dsmethod.c b/source/components/dispatcher/dsmethod.c
index 84d9138e0..b2dc658ec 100644
--- a/source/components/dispatcher/dsmethod.c
+++ b/source/components/dispatcher/dsmethod.c
@@ -247,9 +247,9 @@ AcpiDsDetectNamedOpcodes (
ACPI_FUNCTION_NAME (AcpiDsDetectNamedOpcodes);
- /* We are only interested in opcodes that have an associated name */
+ /* We are only interested in opcodes that create a new name */
- if (!(WalkState->OpInfo->Flags & AML_NAMED))
+ if (!(WalkState->OpInfo->Flags & (AML_NAMED | AML_CREATE | AML_FIELD)))
{
return (AE_OK);
}
@@ -268,7 +268,7 @@ AcpiDsDetectNamedOpcodes (
/* Abort the parse, no need to examine this method any further */
- return_ACPI_STATUS (AE_CTRL_TERMINATE);
+ return (AE_CTRL_TERMINATE);
}